"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const sift_1 = require("sift");
const api = require("../api");
const Service_1 = require("../Service");
exports.get = (req, res) => {
    const services = Service_1.default.all().map(service => {
        const ret = service.export();
        ret.hasLogoData = service.hasLogoData;
        return ret;
    });
    services.sort((a, b) => getOrder(a) - getOrder(b));
    api.responseJSON(res, sift_1.default(req.query, services));
};
function getOrder(service) {
    let order;
    switch (service.channel.type) {
        case "GR":
            order = "1";
            break;
        case "BS":
            order = "2";
            break;
        case "CS":
            order = "3";
            break;
        case "SKY":
            order = "4";
            break;
    }
    if (service.remoteControlKeyId) {
        order += (100 + service.remoteControlKeyId).toString(10);
    }
    else {
        order += "200";
    }
    order += (10000 + service.serviceId).toString(10);
    return parseInt(order, 10);
}
exports.get.apiDoc = {
    tags: ["services"],
    operationId: "getServices",
    parameters: [
        {
            in: "query",
            name: "serviceId",
            type: "integer",
            required: false
        },
        {
            in: "query",
            name: "networkId",
            type: "integer",
            required: false
        },
        {
            in: "query",
            name: "name",
            type: "string",
            required: false
        },
        {
            in: "query",
            name: "type",
            type: "integer",
            required: false
        },
        {
            in: "query",
            name: "channel.type",
            type: "string",
            enum: ["GR", "BS", "CS", "SKY"],
            required: false
        },
        {
            in: "query",
            name: "channel.channel",
            type: "string",
            required: false
        }
    ],
    responses: {
        200: {
            description: "OK",
            schema: {
                type: "array",
                items: {
                    $ref: "#/definitions/Service"
                }
            }
        },
        default: {
            description: "Unexpected Error",
            schema: {
                $ref: "#/definitions/Error"
            }
        }
    }
};

//# sourceMappingURL=services.js.map
