"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = require("fs");
const path_1 = require("path");
const child_process_1 = require("child_process");
const os_1 = require("os");
const tail_1 = require("tail");
const latestVersion = require("latest-version");
const api = require("../../api");
const current = require("../../../../package.json").version;
exports.put = (req, res) => __awaiter(this, void 0, void 0, function* () {
    if (!req.query.force && !process.env.pm_uptime && !process.env.USING_WINSER) {
        api.responseError(res, 500);
        return;
    }
    const latest = yield latestVersion("mirakurun");
    if (!req.query.force && current === latest) {
        api.responseError(res, 409, "Update Nothing");
        return;
    }
    res.setHeader("Content-Type", "text/plain; charset=utf-8");
    res.status(202);
    res.write("Updating...\n");
    const path = path_1.join(os_1.tmpdir(), "Mirakurun_Updating.log");
    if (fs_1.existsSync(path) === true) {
        fs_1.unlinkSync(path);
    }
    const out = fs_1.openSync(path, "a");
    const err = fs_1.openSync(path, "a");
    res.write(`> node lib/updater\n\n`);
    const npm = child_process_1.spawn("node", ["lib/updater"], {
        detached: true,
        stdio: ["ignore", out, err]
    });
    npm.unref();
    const tail = new tail_1.Tail(path);
    tail.on("line", data => res.write(data + "\n"));
    req.once("close", () => {
        tail.removeAllListeners("line");
        tail.unwatch();
    });
});
exports.put.apiDoc = {
    tags: ["version"],
    operationId: "updateVersion",
    produces: [
        "text/plain",
        "application/json"
    ],
    parameters: [
        {
            in: "query",
            name: "force",
            type: "boolean",
            required: false
        }
    ],
    responses: {
        202: {
            description: "Accepted"
        },
        409: {
            description: "Update Nothing",
            schema: {
                $ref: "#/definitions/Error"
            }
        },
        default: {
            description: "Unexpected Error",
            schema: {
                $ref: "#/definitions/Error"
            }
        }
    }
};

//# sourceMappingURL=update.js.map
