"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/*
   Copyright 2016 Yuki KAN

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
*/
const events_1 = require("events");
const util = require("util");
var LogLevel;
(function (LogLevel) {
    LogLevel[LogLevel["FATAL"] = -1] = "FATAL";
    LogLevel[LogLevel["ERROR"] = 0] = "ERROR";
    LogLevel[LogLevel["WARN"] = 1] = "WARN";
    LogLevel[LogLevel["INFO"] = 2] = "INFO";
    LogLevel[LogLevel["DEBUG"] = 3] = "DEBUG";
})(LogLevel = exports.LogLevel || (exports.LogLevel = {}));
exports.logLevel = LogLevel.INFO;
exports.maxLogHistory = 1000;
let offsetStr;
let offsetMS = 0;
if (/ GMT\+\d{4} /.test(new Date().toString()) === true) {
    const date = new Date();
    offsetStr = date.toString().match(/ GMT(\+\d{4}) /)[1];
    offsetStr = offsetStr.slice(0, 3) + ":" + offsetStr.slice(3, 5);
    offsetMS = date.getTimezoneOffset() * 60 * 1000;
}
class LogEvent extends events_1.EventEmitter {
    constructor() {
        super(...arguments);
        this.logs = [];
    }
    emit(ev, level, log) {
        this.logs.push(log);
        if (this.logs.length > exports.maxLogHistory) {
            this.logs.shift();
        }
        switch (level) {
            case LogLevel.DEBUG:
                console.log(log);
                break;
            case LogLevel.INFO:
                console.info(log);
                break;
            case LogLevel.WARN:
                console.warn(log);
                break;
            case LogLevel.ERROR:
            case LogLevel.FATAL:
                console.error(log);
                break;
        }
        return super.emit(ev, log);
    }
    debug(...msgs) {
        if (exports.logLevel >= LogLevel.DEBUG) {
            this.emit("data", LogLevel.DEBUG, getLogString.call(null, "debug", arguments));
        }
    }
    info(...msgs) {
        if (exports.logLevel >= LogLevel.INFO) {
            this.emit("data", LogLevel.INFO, getLogString.call(null, "info", arguments));
        }
    }
    warn(...msgs) {
        if (exports.logLevel >= LogLevel.WARN) {
            this.emit("data", LogLevel.WARN, getLogString.call(null, "warn", arguments));
        }
    }
    error(...msgs) {
        if (exports.logLevel >= LogLevel.ERROR) {
            this.emit("data", LogLevel.ERROR, getLogString.call(null, "error", arguments));
        }
    }
    fatal(...msgs) {
        if (exports.logLevel >= LogLevel.FATAL) {
            this.emit("data", LogLevel.FATAL, getLogString.call(null, "fatal", arguments));
        }
    }
    write(line) {
        this.emit("data", LogLevel.INFO, line.slice(0, -1));
    }
}
exports.event = new LogEvent();
function getLogString(lvstr, msgs) {
    let isoStr;
    if (offsetStr) {
        isoStr = new Date(Date.now() - offsetMS).toISOString();
        isoStr = isoStr.slice(0, -1) + offsetStr;
    }
    else {
        isoStr = new Date().toISOString();
    }
    return isoStr + " " + lvstr + ": " + util.format.apply(null, msgs);
}
exports.debug = (...msgs) => exports.event.debug(...msgs);
exports.info = (...msgs) => exports.event.info(...msgs);
exports.warn = (...msgs) => exports.event.warn(...msgs);
exports.error = (...msgs) => exports.event.error(...msgs);
exports.fatal = (...msgs) => exports.event.fatal(...msgs);

//# sourceMappingURL=log.js.map
